pub fn active_grants_for_actor<'a>(
sessions: impl Iterator<Item = &'a StoredSession>,
actor_id: &ActorId,
) -> Vec<PolicyGrant>Expand description
Returns the active grants for one actor across a collection of stored views.
pub fn active_grants_for_actor<'a>(
sessions: impl Iterator<Item = &'a StoredSession>,
actor_id: &ActorId,
) -> Vec<PolicyGrant>Returns the active grants for one actor across a collection of stored views.