pub struct BranchSummary { /* private fields */ }Expand description
Summary of one durable branch.
Implementations
Sourceimpl BranchSummary
impl BranchSummary
Sourcepub const fn source_branch_id(&self) -> Option<BranchId>
pub const fn source_branch_id(&self) -> Option<BranchId>
Returns source branch for a fork, or None for the root branch.
Sourcepub const fn from_record_id(&self) -> RecordId
pub const fn from_record_id(&self) -> RecordId
Returns the durable source position used to create this branch.
Sourcepub const fn leaf_record_id(&self) -> RecordId
pub const fn leaf_record_id(&self) -> RecordId
Returns the current durable leaf record.