MaterializedSessionState

Struct MaterializedSessionState 

pub struct MaterializedSessionState { /* private fields */ }
Deterministic session projection derived only from the append-only record log.

Implementations

Source

impl MaterializedSessionState

pub const fn session_id(&self) -> SessionId

Returns session identity.

pub const fn tail_sequence(&self) -> SessionSequence

Returns the current authoritative tail sequence.

pub const fn tail_record_id(&self) -> RecordId

Returns the current tail record identity.

pub const fn metadata(&self) -> &ProtocolMetadata

Returns bounded creation metadata.

pub const fn configuration(&self) -> &SessionConfiguration

Returns active configuration.

pub fn messages(&self) -> &[CanonicalMessage]

Returns the active durable transcript.

pub const fn pending_approvals(&self) -> &BTreeMap<ApprovalId, PendingApproval>

Returns pending approvals in stable ID order.

pub const fn tool_calls(&self) -> &BTreeMap<ToolCallId, ToolCallState>

Returns tool-call lifecycle projections in stable ID order.

pub const fn active_branch_id(&self) -> Option<BranchId>

Returns active branch, or None for a legacy unbranched Protocol 1.0 log.

pub const fn branches(&self) -> &BTreeMap<BranchId, BranchSummary>

Returns durable branch summaries in stable ID order.

pub const fn run_recovery(&self) -> &BTreeMap<RunId, RunRecoveryState>

Returns provider-run restart diagnostics.

pub const fn latest_checkpoint(&self) -> Option<&TurnCheckpoint>

Returns the latest durable turn checkpoint.

pub const fn latest_compaction(&self) -> Option<&SessionCompaction>

Returns the latest compaction summary without removing original messages.